#[repr(u8)]pub enum Overrunf {
OVERRUNF_0 = 0,
OVERRUNF_1 = 1,
}Variants
OVERRUNF_0 = 0
there is trigger or ips bus writing during scan progress
OVERRUNF_1 = 1
there is no trigger or ips bus writing during scan progress
Implementations