#[repr(u8)]pub enum SincOverflowFlag {
SINC_OVERFLOW_FLAG_0 = 0,
SINC_OVERFLOW_FLAG_1 = 1,
}Variants
SINC_OVERFLOW_FLAG_0 = 0
The counter result has no overflow occurrence in the last scan process
SINC_OVERFLOW_FLAG_1 = 1
The counter result has an overflow occurrence in the last scan process
Implementations