#[repr(u8)]pub enum TsicntOverflowFlag {
TSICNT_OVERFLOW_FLAG_0 = 0,
TSICNT_OVERFLOW_FLAG_1 = 1,
}Variants
TSICNT_OVERFLOW_FLAG_0 = 0
The DATA[TSICNT] value has no overflow occurrence in the last scan process
TSICNT_OVERFLOW_FLAG_1 = 1
The DATA[TSICNT] value has an overflow occurrence in the last scan process
Implementations